gatein SVN: r6479 - portal/branches/branch-showinfobar/webui/portal/src/main/java/org/exoplatform/portal/webui/portal.
by do-not-reply@jboss.org
Author: kien_nguyen
Date: 2011-05-18 03:12:47 -0400 (Wed, 18 May 2011)
New Revision: 6479
Modified:
portal/branches/branch-showinfobar/webui/portal/src/main/java/org/exoplatform/portal/webui/portal/UIPortalComponentActionListener.java
Log:
GTNPORTAL-1558 change how to get portalConfig
Modified: portal/branches/branch-showinfobar/webui/portal/src/main/java/org/exoplatform/portal/webui/portal/UIPortalComponentActionListener.java
===================================================================
--- components/mop/trunk/api/pom.xml 2011-05-17 20:57:01 UTC (rev 6476)
+++ components/mop/trunk/api/pom.xml 2011-05-17 20:57:14 UTC (rev 6477)
@@ -25,7 +25,7 @@
<parent>
<groupId>org.gatein.mop</groupId>
<artifactId>mop-parent</artifactId>
- <version>1.1.0-Beta02</version>
+ <version>1.1.0-Beta03-SNAPSHOT</version>
</parent>
<!-- ****************** -->
Modified: components/mop/trunk/core/pom.xml
===================================================================
--- components/mop/trunk/core/pom.xml 2011-05-17 20:57:01 UTC (rev 6476)
+++ components/mop/trunk/core/pom.xml 2011-05-17 20:57:14 UTC (rev 6477)
@@ -25,7 +25,7 @@
<parent>
<groupId>org.gatein.mop</groupId>
<artifactId>mop-parent</artifactId>
- <version>1.1.0-Beta02</version>
+ <version>1.1.0-Beta03-SNAPSHOT</version>
</parent>
<!-- ****************** -->
Modified: components/mop/trunk/pom.xml
===================================================================
--- components/mop/trunk/pom.xml 2011-05-17 20:57:01 UTC (rev 6476)
+++ components/mop/trunk/pom.xml 2011-05-17 20:57:14 UTC (rev 6477)
@@ -34,16 +34,16 @@
<groupId>org.gatein.mop</groupId>
<artifactId>mop-parent</artifactId>
- <version>1.1.0-Beta02</version>
+ <version>1.1.0-Beta03-SNAPSHOT</version>
<packaging>pom</packaging>
<name>GateIn - MOP</name>
<description>Model Object for Portal</description>
<scm>
- <connection>scm:svn:http://anonsvn.jboss.org/repos/gatein/components/mop/tags/1.1.0-B...</connection>
- <developerConnection>scm:svn:https://svn.jboss.org/repos/gatein/components/mop/tags/1.1.0-Beta02</developerConnection>
- <url>http://fisheye.jboss.org/browse/gatein/components/mop/tags/1.1.0-Beta02</url>
+ <connection>scm:svn:http://anonsvn.jboss.org/repos/gatein/components/mop/trunk/</connection>
+ <developerConnection>scm:svn:https://svn.jboss.org/repos/gatein/components/mop/trunk/</developerConnection>
+ <url>http://fisheye.jboss.org/browse/gatein/components/mop/trunk/</url>
</scm>
<dependencyManagement>
Modified: components/mop/trunk/spi/pom.xml
===================================================================
--- components/mop/trunk/spi/pom.xml 2011-05-17 20:57:01 UTC (rev 6476)
+++ components/mop/trunk/spi/pom.xml 2011-05-17 20:57:14 UTC (rev 6477)
@@ -25,7 +25,7 @@
<parent>
<groupId>org.gatein.mop</groupId>
<artifactId>mop-parent</artifactId>
- <version>1.1.0-Beta02</version>
+ <version>1.1.0-Beta03-SNAPSHOT</version>
</parent>
<!-- ****************** -->
13 years, 7 months
gatein SVN: r6476 - components/mop/tags.
by do-not-reply@jboss.org
Author: julien_viet
Date: 2011-05-17 16:57:01 -0400 (Tue, 17 May 2011)
New Revision: 6476
Added:
components/mop/tags/1.1.0-Beta02/
Log:
[maven-scm] copy for tag 1.1.0-Beta02
13 years, 7 months
gatein SVN: r6475 - in components/mop/trunk: api and 2 other directories.
by do-not-reply@jboss.org
Author: julien_viet
Date: 2011-05-17 16:56:35 -0400 (Tue, 17 May 2011)
New Revision: 6475
Modified:
components/mop/trunk/api/pom.xml
components/mop/trunk/core/pom.xml
components/mop/trunk/pom.xml
components/mop/trunk/spi/pom.xml
Log:
[maven-release-plugin] prepare release 1.1.0-Beta02
Modified: components/mop/trunk/api/pom.xml
===================================================================
--- components/mop/trunk/api/pom.xml 2011-05-17 20:53:41 UTC (rev 6474)
+++ components/mop/trunk/api/pom.xml 2011-05-17 20:56:35 UTC (rev 6475)
@@ -25,7 +25,7 @@
<parent>
<groupId>org.gatein.mop</groupId>
<artifactId>mop-parent</artifactId>
- <version>1.1.0-Beta02-SNAPSHOT</version>
+ <version>1.1.0-Beta02</version>
</parent>
<!-- ****************** -->
Modified: components/mop/trunk/core/pom.xml
===================================================================
--- components/mop/trunk/core/pom.xml 2011-05-17 20:53:41 UTC (rev 6474)
+++ components/mop/trunk/core/pom.xml 2011-05-17 20:56:35 UTC (rev 6475)
@@ -25,7 +25,7 @@
<parent>
<groupId>org.gatein.mop</groupId>
<artifactId>mop-parent</artifactId>
- <version>1.1.0-Beta02-SNAPSHOT</version>
+ <version>1.1.0-Beta02</version>
</parent>
<!-- ****************** -->
Modified: components/mop/trunk/pom.xml
===================================================================
--- components/mop/trunk/pom.xml 2011-05-17 20:53:41 UTC (rev 6474)
+++ components/mop/trunk/pom.xml 2011-05-17 20:56:35 UTC (rev 6475)
@@ -34,16 +34,16 @@
<groupId>org.gatein.mop</groupId>
<artifactId>mop-parent</artifactId>
- <version>1.1.0-Beta02-SNAPSHOT</version>
+ <version>1.1.0-Beta02</version>
<packaging>pom</packaging>
<name>GateIn - MOP</name>
<description>Model Object for Portal</description>
<scm>
- <connection>scm:svn:http://anonsvn.jboss.org/repos/gatein/components/mop/trunk/</connection>
- <developerConnection>scm:svn:https://svn.jboss.org/repos/gatein/components/mop/trunk/</developerConnection>
- <url>http://fisheye.jboss.org/browse/gatein/components/mop/trunk/</url>
+ <connection>scm:svn:http://anonsvn.jboss.org/repos/gatein/components/mop/tags/1.1.0-B...</connection>
+ <developerConnection>scm:svn:https://svn.jboss.org/repos/gatein/components/mop/tags/1.1.0-Beta02</developerConnection>
+ <url>http://fisheye.jboss.org/browse/gatein/components/mop/tags/1.1.0-Beta02</url>
</scm>
<dependencyManagement>
Modified: components/mop/trunk/spi/pom.xml
===================================================================
--- components/mop/trunk/spi/pom.xml 2011-05-17 20:53:41 UTC (rev 6474)
+++ components/mop/trunk/spi/pom.xml 2011-05-17 20:56:35 UTC (rev 6475)
@@ -25,7 +25,7 @@
<parent>
<groupId>org.gatein.mop</groupId>
<artifactId>mop-parent</artifactId>
- <version>1.1.0-Beta02-SNAPSHOT</version>
+ <version>1.1.0-Beta02</version>
</parent>
<!-- ****************** -->
13 years, 7 months
gatein SVN: r6474 - components/mop/trunk.
by do-not-reply@jboss.org
Author: julien_viet
Date: 2011-05-17 16:53:41 -0400 (Tue, 17 May 2011)
New Revision: 6474
Modified:
components/mop/trunk/pom.xml
Log:
GTNMOP-37 : Upgrade to JCR 1.14.0-CR2 and Chromattic 1.1.0-beta5
Modified: components/mop/trunk/pom.xml
===================================================================
--- components/mop/trunk/pom.xml 2011-05-17 03:10:16 UTC (rev 6473)
+++ components/mop/trunk/pom.xml 2011-05-17 20:53:41 UTC (rev 6474)
@@ -124,7 +124,7 @@
<!-- Build settings -->
<!-- ************** -->
- <org.chromattic.version>1.1.0-beta2</org.chromattic.version>
+ <org.chromattic.version>1.1.0-beta5</org.chromattic.version>
<!--
Current testuite doesn't work with surefire 2.7 defined in parent pom
13 years, 7 months
gatein SVN: r6473 - portal/branches.
by do-not-reply@jboss.org
Author: trong.tran
Date: 2011-05-16 23:10:16 -0400 (Mon, 16 May 2011)
New Revision: 6473
Removed:
portal/branches/decoupled-webos/
Log:
Remove decoupled-webos branch which was merged into trunk
13 years, 7 months
gatein SVN: r6472 - portal/branches.
by do-not-reply@jboss.org
Author: trong.tran
Date: 2011-05-16 23:09:29 -0400 (Mon, 16 May 2011)
New Revision: 6472
Removed:
portal/branches/site-describability/
Log:
Remove site-describability branch which was merged into trunk
13 years, 7 months
gatein SVN: r6471 - portal/branches/branch-showinfobar/webui/portal/src/main/java/org/exoplatform/portal/webui/portal.
by do-not-reply@jboss.org
Author: kien_nguyen
Date: 2011-05-15 22:41:01 -0400 (Sun, 15 May 2011)
New Revision: 6471
Modified:
portal/branches/branch-showinfobar/webui/portal/src/main/java/org/exoplatform/portal/webui/portal/UIPortalComponentActionListener.java
Log:
GTNPORTAL-1558 fix bug getting portal
Modified: portal/branches/branch-showinfobar/webui/portal/src/main/java/org/exoplatform/portal/webui/portal/UIPortalComponentActionListener.java
===================================================================
--- portal/branches/branch-showinfobar/webui/portal/src/main/java/org/exoplatform/portal/webui/portal/UIPortalComponentActionListener.java 2011-05-13 01:23:40 UTC (rev 6470)
+++ portal/branches/branch-showinfobar/webui/portal/src/main/java/org/exoplatform/portal/webui/portal/UIPortalComponentActionListener.java 2011-05-16 02:41:01 UTC (rev 6471)
@@ -336,7 +336,7 @@
//TODO Wait to fix issue EXOGTN-213 and then
//we should get "showInfobar" from current UI portal
UserPortalConfigService service = uiApp.getApplicationComponent(UserPortalConfigService.class);
- uiPortlet.setShowInfoBar(service.getUserPortalConfig(Util.getUIPortal().getOwner(), pcontext.getRemoteUser()).getPortalConfig().isShowInfobar());
+ uiPortlet.setShowInfoBar(service.getUserPortalConfig(pcontext.getPortalOwner(), pcontext.getRemoteUser()).getPortalConfig().isShowInfobar());
uiSource = uiPortlet;
}
List<UIComponent> children = uiTarget.getChildren();
13 years, 7 months
gatein SVN: r6470 - in epp/docs/branches/5.1/Reference_Guide/en-US: extras and 3 other directories.
by do-not-reply@jboss.org
Author: smumford
Date: 2011-05-12 21:23:40 -0400 (Thu, 12 May 2011)
New Revision: 6470
Added:
epp/docs/branches/5.1/Reference_Guide/en-US/extras/Authentication_Identity/
epp/docs/branches/5.1/Reference_Guide/en-US/extras/Authentication_Identity/ExampleCodec.java
epp/docs/branches/5.1/Reference_Guide/en-US/extras/Authentication_Identity/configuration.xml
Modified:
epp/docs/branches/5.1/Reference_Guide/en-US/Book_Info.xml
epp/docs/branches/5.1/Reference_Guide/en-US/Reference_Guide.ent
epp/docs/branches/5.1/Reference_Guide/en-US/Revision_History.xml
epp/docs/branches/5.1/Reference_Guide/en-US/modules/AuthenticationAndIdentity.xml
epp/docs/branches/5.1/Reference_Guide/en-US/modules/AuthenticationAndIdentity/AccessingUserProfile.xml
epp/docs/branches/5.1/Reference_Guide/en-US/modules/AuthenticationAndIdentity/AuthenticationTokenConfiguration.xml
epp/docs/branches/5.1/Reference_Guide/en-US/modules/WSRP.xml
Log:
JBEPP-610: Added new example encrytopin codec java file and actioned feedback
Modified: epp/docs/branches/5.1/Reference_Guide/en-US/Book_Info.xml
===================================================================
--- epp/docs/branches/5.1/Reference_Guide/en-US/Book_Info.xml 2011-05-12 11:24:49 UTC (rev 6469)
+++ epp/docs/branches/5.1/Reference_Guide/en-US/Book_Info.xml 2011-05-13 01:23:40 UTC (rev 6470)
@@ -9,7 +9,7 @@
<productname>JBoss Enterprise Portal Platform</productname>
<productnumber>5.1</productnumber>
<edition>1</edition>
- <pubsnumber>5.3</pubsnumber>
+ <pubsnumber>5.5</pubsnumber>
<abstract>
<para>
This Reference Guide is a high-level usage document. It deals with more advanced topics than the Installation and User Guides, adding new content or taking concepts discussed in the earlier documents further. It aims to provide supporting documentation for advanced users of the JBoss Enterprise Portal Platform product. Its primary focus is on advanced use of the product and it assumes an intermediate or advanced knowledge of the technology and terms.
Modified: epp/docs/branches/5.1/Reference_Guide/en-US/Reference_Guide.ent
===================================================================
--- epp/docs/branches/5.1/Reference_Guide/en-US/Reference_Guide.ent 2011-05-12 11:24:49 UTC (rev 6469)
+++ epp/docs/branches/5.1/Reference_Guide/en-US/Reference_Guide.ent 2011-05-13 01:23:40 UTC (rev 6470)
@@ -7,3 +7,8 @@
<!-- Corporate Specifics: -->
<!ENTITY YEAR "2010">
<!ENTITY HOLDER "Red Hat, Inc">
+
+<!-- Version Specifcs: -->
+<!ENTITY VX "5">
+<!ENTITY VY "5.1">
+<!ENTITY VZ "5.1.1">
\ No newline at end of file
Modified: epp/docs/branches/5.1/Reference_Guide/en-US/Revision_History.xml
===================================================================
--- epp/docs/branches/5.1/Reference_Guide/en-US/Revision_History.xml 2011-05-12 11:24:49 UTC (rev 6469)
+++ epp/docs/branches/5.1/Reference_Guide/en-US/Revision_History.xml 2011-05-13 01:23:40 UTC (rev 6470)
@@ -8,8 +8,8 @@
<simpara>
<revhistory>
<revision>
- <revnumber>1-5.3</revnumber>
- <date>Tue Apr 5 2011</date>
+ <revnumber>1-5.5</revnumber>
+ <date>Thu May 12 2011</date>
<author>
<firstname>Scott</firstname>
<surname>Mumford</surname>
@@ -17,6 +17,20 @@
</author>
<revdescription>
<simplelist>
+ <member>Added 'Password Encryption' Draft.</member>
+ </simplelist>
+ </revdescription>
+ </revision>
+ <revision>
+ <revnumber>1-5.4</revnumber>
+ <date>Wed Apr 27 2011</date>
+ <author>
+ <firstname>Scott</firstname>
+ <surname>Mumford</surname>
+ <email>smumford(a)redhat.com</email>
+ </author>
+ <revdescription>
+ <simplelist>
<member>Completed first draft of new LDAP section.</member>
</simplelist>
</revdescription>
@@ -35,7 +49,7 @@
</simplelist>
</revdescription>
</revision>
- <revision>
+ <!-- <revision>
<revnumber>1-5.1</revnumber>
<date>Tue Dec 21 2010</date>
<author>
@@ -77,7 +91,7 @@
</simplelist>
</revdescription>
</revision>
- <!-- <revision>
+ <revision>
<revnumber>1-4.2</revnumber>
<date>Mon Dec 13 2010</date>
<author>
Added: epp/docs/branches/5.1/Reference_Guide/en-US/extras/Authentication_Identity/ExampleCodec.java
===================================================================
--- epp/docs/branches/5.1/Reference_Guide/en-US/extras/Authentication_Identity/ExampleCodec.java (rev 0)
+++ epp/docs/branches/5.1/Reference_Guide/en-US/extras/Authentication_Identity/ExampleCodec.java 2011-05-13 01:23:40 UTC (rev 6470)
@@ -0,0 +1,43 @@
+package org.example.codec;
+
+import org.exoplatform.container.xml.InitParams;
+import org.exoplatform.web.security.security.AbstractCodec;
+import org.exoplatform.web.security.security.CookieTokenService;
+import org.picocontainer.Startable;
+
+public class ExampleCodec extends AbstractCodec implements Startable
+{
+ private String simpleParam;
+ private CookieTokenService cookieTokenService;
+
+ public ExampleCodec(InitParams params, CookieTokenService cookieTokenService)
+ {
+ simpleParam = params.getValueParam("encodingParam").getValue();
+ this.cookieTokenService = cookieTokenService;
+ }
+
+ public void start()
+ {
+ cookieTokenService.setupCodec(this);
+ }
+
+ public void stop()
+ {
+ }
+
+ /**
+ * Very simple encoding algorithm used only for demonstration purposes.
+ * You should use stronger algorithm in real production environment.
+ */
+ public String encode(String plainInput)
+ {
+ return plainInput + simpleParam;
+ }
+
+ public String decode(String encodedInput)
+ {
+ return encodedInput.substring(0, encodedInput.length() - simpleParam.length());
+ }
+
+}
+
Added: epp/docs/branches/5.1/Reference_Guide/en-US/extras/Authentication_Identity/configuration.xml
===================================================================
--- epp/docs/branches/5.1/Reference_Guide/en-US/extras/Authentication_Identity/configuration.xml (rev 0)
+++ epp/docs/branches/5.1/Reference_Guide/en-US/extras/Authentication_Identity/configuration.xml 2011-05-13 01:23:40 UTC (rev 6470)
@@ -0,0 +1,18 @@
+<?xml version="1.0" encoding="ISO-8859-1"?>
+
+<configuration xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
+xsi:schemaLocation="http://www.exoplaform.org/xml/ns/kernel_1_0.xsd http://www.exoplaform.org/xml/ns/kernel_1_0.xsd"
+xmlns="http://www.exoplaform.org/xml/ns/kernel_1_0.xsd">
+
+<component>
+ <key>org.example.codec.ExampleCodec</key>
+ <type>org.example.codec.ExampleCodec</type>
+ <init-params>
+ <value-param>
+ <name>encodingParam</name>
+ <value>aaa</value>
+ </value-param>
+ </init-params>
+</component>
+
+</configuration>
\ No newline at end of file
Modified: epp/docs/branches/5.1/Reference_Guide/en-US/modules/AuthenticationAndIdentity/AccessingUserProfile.xml
===================================================================
--- epp/docs/branches/5.1/Reference_Guide/en-US/modules/AuthenticationAndIdentity/AccessingUserProfile.xml 2011-05-12 11:24:49 UTC (rev 6469)
+++ epp/docs/branches/5.1/Reference_Guide/en-US/modules/AuthenticationAndIdentity/AccessingUserProfile.xml 2011-05-13 01:23:40 UTC (rev 6470)
@@ -10,23 +10,7 @@
</para>
<programlisting language="Java" role="Java"><xi:include href="../../extras/Authentication_Identity_AccessingUserProfile/default91.java" parse="text" xmlns:xi="http://www.w3.org/2001/XInclude" /></programlisting>
- <!-- <programlisting language="Java" role="JAVA">// Alternative context: WebuiRequestContext context = WebuiRequestContext.getCurrentInstance() ;
-PortalRequestContext context = PortalRequestContext.getCurrentInstance() ;
-// Get the id of the user logged
-String userId = context.getRemoteUser();
-// Request the information from OrganizationService:
-OrganizationService orgService = getApplicationComponent(OrganizationService.class) ;
-if (userId != null)
-{
-User user = orgService.getUserHandler().findUserByName(userId) ;
-if (user != null)
-{
-String firstName = user.getFirstName();
-String lastName = user.getLastName();
-String email = user.getEmail();
-}
-}
-</programlisting> -->
+
<para>
Below are two alternatives for retrieving the Organization Service:
</para>
@@ -34,16 +18,12 @@
<listitem>
<programlisting language="Java" role="Java"><xi:include href="../../extras/Authentication_Identity_AccessingUserProfile/default92.java" parse="text" xmlns:xi="http://www.w3.org/2001/XInclude" /></programlisting>
- <!-- <programlisting language="Java" role="JAVA">OrganizationService service = (OrganizationService)
-ExoContainerContext.getCurrentContainer().getComponentInstanceOfType(OrganizationService.class);
-</programlisting> -->
+
</listitem>
<listitem>
<programlisting language="Java" role="Java"><xi:include href="../../extras/Authentication_Identity_AccessingUserProfile/default93.java" parse="text" xmlns:xi="http://www.w3.org/2001/XInclude" /></programlisting>
- <!-- <programlisting language="Java" role="JAVA">OrganizationService service = (OrganizationService)
-PortalContainer.getInstance().getComponentInstanceOfType(OrganizationService.class);
-</programlisting> -->
+
</listitem>
</orderedlist>
</section>
Modified: epp/docs/branches/5.1/Reference_Guide/en-US/modules/AuthenticationAndIdentity/AuthenticationTokenConfiguration.xml
===================================================================
--- epp/docs/branches/5.1/Reference_Guide/en-US/modules/AuthenticationAndIdentity/AuthenticationTokenConfiguration.xml 2011-05-12 11:24:49 UTC (rev 6469)
+++ epp/docs/branches/5.1/Reference_Guide/en-US/modules/AuthenticationAndIdentity/AuthenticationTokenConfiguration.xml 2011-05-13 01:23:40 UTC (rev 6470)
@@ -16,15 +16,6 @@
<para>
The token service allows administrators to create, delete, retrieve and clean tokens as required. The service also defines a validity period of any given token. The token becomes invalid once this period expires.
</para>
- <warning>
- <title>Username and passwords stored in clear text</title>
- <para>
- The remember-me feature uses the token mechanism to be able to authenticate returning users without requiring an explicit login. To be able to authenticate, the token needs to store the username and password in clear text in the JCR.
- </para>
- <para>
- The remember-me feature can be disabled by removing the corresponding checkbox in: <filename><replaceable>JBOSS_HOME</replaceable>/server/<replaceable><PROFILE></replaceable>/deploy/gatein.ear/02portal.war/login/jsp/login.jsp</filename> and <filename><replaceable>JBOSS_HOME</replaceable>/server/<replaceable><PROFILE></replaceable>/deploy/gatein.ear/02portal.war/groovy/portal/webui/UILoginForm.gtmpl</filename>
- </para>
- </warning>
</section>
Modified: epp/docs/branches/5.1/Reference_Guide/en-US/modules/AuthenticationAndIdentity.xml
===================================================================
--- epp/docs/branches/5.1/Reference_Guide/en-US/modules/AuthenticationAndIdentity.xml 2011-05-12 11:24:49 UTC (rev 6469)
+++ epp/docs/branches/5.1/Reference_Guide/en-US/modules/AuthenticationAndIdentity.xml 2011-05-13 01:23:40 UTC (rev 6470)
@@ -4,7 +4,66 @@
%BOOK_ENTITIES;
]>
<chapter id="chap-Reference_Guide-Authentication_and_Identity">
- <title>Authentication and Identity</title>
+ <title>Authentication and Identity</title>
+ <section id="sect-Reference_Guide-Authentication_and_Identity-Password_Encryption" >
+ <title><remark>Password Encryption</remark></title>
+ <!--The warning and first listitem below were relocated from sect-Reference_Guide-Authentication_Token_Configuration as security and plain-text password issues were being expanded on (from JBEPP-610)-->
+ <warning>
+ <title>Username and passwords stored in clear text</title>
+ <para>
+ The <emphasis>Remember Me</emphasis> feature of JBoss Enterprise Portal Platform uses a token mechanism to be able to authenticate returning users without requiring an explicit login. However, to be able to authenticate these users, the token needs to store the username and password in clear text in the JCR.
+ </para>
+ </warning>
+ <para>
+ Administrators have two options available to ameliorate this risk:
+ </para>
+ <orderedlist>
+ <listitem>
+ <para>
+ The <emphasis>Remember Me</emphasis> feature can be disabled by removing the corresponding checkbox in: <filename><replaceable><JBOSS_HOME></replaceable>/server/<replaceable><PROFILE></replaceable>/deploy/gatein.ear/02portal.war/login/jsp/login.jsp</filename> and <filename><replaceable><JBOSS_HOME></replaceable>/server/<replaceable><PROFILE></replaceable>/deploy/gatein.ear/02portal.war/groovy/portal/webui/UILoginForm.gtmpl</filename>.
+ </para>
+ </listitem>
+ <listitem>
+ <para>
+ Passwords can be encoded prior to being saved to the JCR. This option requires administrators to provide a custom subclass of <parameter>org.exoplatform.web.security.security.AbstractCodec</parameter> and set up a codec implementation with <parameter>CookieTokenService</parameter>:
+ </para>
+ <procedure>
+ <title>Encrypt Password in JCR</title>
+ <step>
+ <para>
+ Create a javaclass similar to:
+ </para>
+<programlisting language="Java" role="Java"><xi:include href="../extras/Authentication_Identity/ExampleCodec.java" parse="text" xmlns:xi="http://www.w3.org/2001/XInclude" /></programlisting>
+ </step>
+ <step>
+ <para>
+ Compile the class and package it into a jar file. For this example we will call the jar file <filename>codec-example.jar</filename>.
+ </para>
+ </step>
+ <step>
+ <para>
+ Create a <filename>conf/portal/configuration.xml</filename> file within the <filename>codec-example.jar</filename> similar to the example below. This allows the portal kernel to find and use the new codec implementation.
+ </para>
+<programlisting language="XML" role="XML"><xi:include href="../extras/Authentication_Identity/configuration.xml" parse="text" xmlns:xi="http://www.w3.org/2001/XInclude" /></programlisting>
+ </step>
+ <step>
+ <para>
+ Deploy the <filename>codec-example.jar</filename> into your <filename><replaceable><JBOSS_HOME></replaceable>/server/<replaceable><PROFILE></replaceable>/deploy/gatein.ear/lib/</filename> directory.
+ </para>
+ </step>
+ <step>
+ <para>
+ Start (or restart) your JBoss Enterprise Portal Platform.
+ </para>
+ <para>
+ Any passwords written to the JCR will now be encoded and not plain-text.
+ </para>
+ </step>
+ </procedure>
+ </listitem>
+ </orderedlist>
+ </section>
+
<xi:include href="AuthenticationAndIdentity/PredefinedUserConfiguration.xml" xmlns:xi="http://www.w3.org/2001/XInclude" />
<xi:include href="AuthenticationAndIdentity/AuthenticationTokenConfiguration.xml" xmlns:xi="http://www.w3.org/2001/XInclude" />
<xi:include href="AuthenticationAndIdentity/BackendConfiguration.xml" xmlns:xi="http://www.w3.org/2001/XInclude" />
Modified: epp/docs/branches/5.1/Reference_Guide/en-US/modules/WSRP.xml
===================================================================
--- epp/docs/branches/5.1/Reference_Guide/en-US/modules/WSRP.xml 2011-05-12 11:24:49 UTC (rev 6469)
+++ epp/docs/branches/5.1/Reference_Guide/en-US/modules/WSRP.xml 2011-05-13 01:23:40 UTC (rev 6470)
@@ -797,7 +797,7 @@
</imageobject>
</mediaobject>
<note>
- <title><emphasis role="bold">JBoss Enterprise Portal Platform 5.0 and WSRP 1 Exceptions</emphasis></title>
+ <title><emphasis role="bold">JBoss Enterprise Portal Platform 5.1 and WSRP 1 Exceptions</emphasis></title>
<para>
In WSRP 1, it can be difficult to ascertain what caused an <exceptionname>OperationFailedFault</exceptionname> as it is a generic exception returned by producers during a failed method invocation.
</para>
13 years, 7 months
--- portal/branches/branch-showinfobar/webui/portal/src/main/java/org/exoplatform/portal/webui/portal/UIPortalComponentActionListener.java 2011-05-18 04:50:59 UTC (rev 6478)
+++ portal/branches/branch-showinfobar/webui/portal/src/main/java/org/exoplatform/portal/webui/portal/UIPortalComponentActionListener.java 2011-05-18 07:12:47 UTC (rev 6479)
@@ -21,12 +21,14 @@
import org.exoplatform.application.registry.Application;
import org.exoplatform.portal.application.PortalRequestContext;
+import org.exoplatform.portal.config.DataStorage;
import org.exoplatform.portal.config.UserACL;
import org.exoplatform.portal.config.UserPortalConfigService;
import org.exoplatform.portal.config.model.ApplicationState;
import org.exoplatform.portal.config.model.ApplicationType;
import org.exoplatform.portal.config.model.CloneApplicationState;
import org.exoplatform.portal.config.model.Container;
+import org.exoplatform.portal.config.model.PortalConfig;
import org.exoplatform.portal.config.model.TransientApplicationState;
import org.exoplatform.portal.webui.application.PortletState;
import org.exoplatform.portal.webui.application.UIPortlet;
@@ -334,9 +336,10 @@
uiPortlet.setShowEditControl(true);
//TODO Wait to fix issue EXOGTN-213 and then
- //we should get "showInfobar" from current UI portal
- UserPortalConfigService service = uiApp.getApplicationComponent(UserPortalConfigService.class);
- uiPortlet.setShowInfoBar(service.getUserPortalConfig(pcontext.getPortalOwner(), pcontext.getRemoteUser()).getPortalConfig().isShowInfobar());
+ //we should get "showInfobar" from current UI portal instead of Storage service
+ UIPortal currentPortal = Util.getUIPortal();
+ DataStorage storage = uiApp.getApplicationComponent(DataStorage.class);
+ uiPortlet.setShowInfoBar(storage.getPortalConfig(currentPortal.getOwnerType(), currentPortal.getOwner()).isShowInfobar());
uiSource = uiPortlet;
}
List<UIComponent> children = uiTarget.getChildren();
13 years, 7 months
gatein SVN: r6478 - portal/trunk/testsuite/testdefinitions.
by do-not-reply@jboss.org
Author: kien_nguyen
Date: 2011-05-18 00:50:59 -0400 (Wed, 18 May 2011)
New Revision: 6478
Added:
portal/trunk/testsuite/testdefinitions/eXo_SniffTest_GateIn_3.1.x_TestDefinition.ods
Modified:
portal/trunk/testsuite/testdefinitions/eXo_SniffTest_GateIn_3.2.x_TestDefinition.ods
Log:
update testcase follow new standard
Added: portal/trunk/testsuite/testdefinitions/eXo_SniffTest_GateIn_3.1.x_TestDefinition.ods
===================================================================
(Binary files differ)
Property changes on: portal/trunk/testsuite/testdefinitions/eXo_SniffTest_GateIn_3.1.x_TestDefinition.ods
___________________________________________________________________
Added: svn:mime-type
+ application/octet-stream
Modified: portal/trunk/testsuite/testdefinitions/eXo_SniffTest_GateIn_3.2.x_TestDefinition.ods
===================================================================
(Binary files differ)
13 years, 7 months
gatein SVN: r6477 - in components/mop/trunk: api and 2 other directories.
by do-not-reply@jboss.org
Author: julien_viet
Date: 2011-05-17 16:57:14 -0400 (Tue, 17 May 2011)
New Revision: 6477
Modified:
components/mop/trunk/api/pom.xml
components/mop/trunk/core/pom.xml
components/mop/trunk/pom.xml
components/mop/trunk/spi/pom.xml
Log:
[maven-release-plugin] prepare for next development iteration
Modified: components/mop/trunk/api/pom.xml
===================================================================